# streamlit-webrtc

## Example
You can try out the sample app using the following commands.
```
$ pip install streamlit-webrtc opencv-python
$ streamlit run https://raw.githubusercontent.com/whitphx/streamlit-webrtc-example/main/app.py
```

You can also try it out here: https://streamlit-webrtc-example.herokuapp.com/; however, it’s running on a very small Heroku instance on a free plan, and may not work well if multiple users access it at the same time.

The deployment of the above example app is managed in this repository: https://github.com/whitphx/streamlit-webrtc-example/.
